YmlGeneratorConfig class

Constructors

YmlGeneratorConfig(PubspecConfig pubspecConfig, String configContent, String fileName)
YmlGeneratorConfig.merge(Iterable<YmlGeneratorConfig> configs, String dirName)

Properties

fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
models → List<Model>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkIfTypesAvailable() → void
checkTypesKnown(Set<String> names, String type) → void
getField(String name, YamlMap property, {required bool disallowNullForDefaults}) → Field
getModelByName(ItemType itemType) → Model?
getPathsForName(PubspecConfig pubspecConfig, String name) → Iterable<String>
getSimpleField({required String name, required String value}) → Field
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited