Field class

Constructors

Field({required String name, required ItemType type, required bool isRequired, required bool ignore, required bool includeFromJson, required bool includeToJson, required bool includeIfNull, required bool nonFinal, required bool ignoreEquality, String? description, String? unknownEnumValue, String? fromJson, String? toJson, String? defaultValue, bool disallowNull = false, String? jsonKey})

Properties

defaultValue → String?
final
description → String?
final
disallowNull → bool
final
fromJson → String?
final
hasDefaultValue → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignore → bool
final
ignoreEquality → bool
final
includeFromJson → bool
final
includeIfNull → bool
final
includeToJson → bool
final
isRequired → bool
final
name → String
final
nonFinal → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializedName → String
final
toJson → String?
final
type → ItemType
final
unknownEnumValue → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited