EnumModel class

Inheritance

Constructors

EnumModel({required String name, required List<EnumField> fields, required List<EnumProperty> properties, required bool generateExtension, bool addJsonValueToProperties = true, String? path, String? baseDirectory, List<String>? extraImports, List<String>? extraAnnotations, String? description})

Properties

addJsonValueToProperties → bool
final
baseDirectory → String?
finalinherited
description → String?
finalinherited
extendsModel → String?
finalinherited
extraAnnotations → List<String>?
finalinherited
extraImports → List<String>?
finalinherited
fields → List<EnumField>
final
fileName → String
finalinherited
generateExtension → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
path → String?
finalinherited
properties → List<EnumProperty>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testValueType<T>({required T? parser(String toParseValue), required String typeName, required String toParseValue, required String propertyName, required String fieldName}) → String?
toString() → String
A string representation of this object.
inherited
validate() → String?

Operators

operator ==(Object other) → bool
The equality operator.
inherited