EnumProperty class

Constructors

EnumProperty({required String name, required ItemType type, required bool isOptional, String? defaultValue, bool isJsonvalue = false})

Properties

defaultValue ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isJsonvalue → bool
final
isOptional → bool
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ItemType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited