JsonConverterModel class

Inheritance

Constructors

JsonConverterModel({required String name, String? path, String? baseDirectory, List<String>? extraImports, List<String>? extraAnnotations})

Properties

baseDirectory → String?
finalinherited
description → String?
finalinherited
extendsModel → String?
finalinherited
extraAnnotations → List<String>?
finalinherited
extraImports → List<String>?
finalinherited
fileName → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
path → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited