Model class abstract

Implementers

Constructors

Model({required String name, required String? path, required String? baseDirectory, required List<String>? extraImports, required List<String>? extraAnnotations, String? extendsModel, String? description})

Properties

baseDirectory → String?
final
description → String?
final
extendsModel → String?
final
extraAnnotations → List<String>?
final
extraImports → List<String>?
final
fileName → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBaseDirectory(String? baseDirectory) → String?
getFileName(String name) → String
getPath(String? path) → String?