ObjectModel class

Inheritance

Constructors

ObjectModel({required String name, required String? path, required String? baseDirectory, required bool generateForGenerics, required List<Field> fields, required List<String> converters, List<String>? extraImports, List<String>? extraAnnotations, String? extendsModel, bool? equalsAndHashCode, bool? explicitToJson, bool? generateToString, bool? staticCreate, bool? disallowNullForDefaults, String? description})

Properties

baseDirectory → String?
finalinherited
converters → List<String>
final
description → String?
finalinherited
disallowNullForDefaults → bool?
final
equalsAndHashCode → bool?
final
explicitToJson → bool?
final
extendsModel → String?
finalinherited
extraAnnotations → List<String>?
finalinherited
extraImports → List<String>?
finalinherited
fields → List<Field>
final
fileName → String
finalinherited
generateForGenerics → bool
final
generateToString → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
path → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticCreate → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited