CaseUtil class

Constructors

CaseUtil(String text)

Properties

camelCase → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
originalText ↔ String
getter/setter pair
pascalCase → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snakeCase → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited